@@ -170,7 +170,11 @@ class ReferencesTest(Testing.ZopeTestCase.FunctionalTestCase):
         self.app['folder']['foo'].my_ref = self.app['folder']['bar']
         response = self.publish(
             '/folder/@@toFS.snarf', basic='manager:asdf')
-        self.assertTrue("""doppelt: [\'<File at foo>\', "{\'precondition\': \'\', \'my_ref\': <File at bar>,""" in response.getBody())
+        self.assertTrue("""Duplicate OId %r: """
+                        """['<File at foo>',"""
+                        """ "{'precondition': '', 'my_ref': <File at bar>,"""
+                        % self.app['folder']['bar']._p_oid
+                        in response.getBody())
 
 
 class FolderTest(Testing.ZopeTestCase.FunctionalTestCase):
